@@ -872,18 +872,31 @@ gdu_utils_show_confirmation (GtkWindow    *parent_window,
 /* ---------------------------------------------------------------------------------------------------- */
 
 gboolean
-gdu_utils_is_ntfs_available (void)
+gdu_utils_is_ntfs_available (UDisksClient *client)
 {
   static gsize once = 0;
   static gboolean available = FALSE;
 
   if (g_once_init_enter (&once))
     {
+#ifdef HAVE_UDISKS2_7_2
+      GVariant *out_available;
+      gchar *missing_util;
+
+      if (udisks_manager_call_can_format_sync (udisks_client_get_manager (client),
+                                               "ntfs", &out_available, NULL, NULL))
+        {
+          g_variant_get (out_available, "(bs)", &available, &missing_util);
+          g_variant_unref (out_available);
+          g_free (missing_util);
+        }
+#else
       gchar *path;
       path = g_find_program_in_path ("mkntfs");
       if (path != NULL)
         available = TRUE;
       g_free (path);
+#endif
       g_once_init_leave (&once, (gsize) 1);
     }
   return available;
